# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0007_initial'),
        ('appointments', '0004_initial'),
        ('base', '0005_initial'),
        ('bodystructures', '0002_initial'),
        ('careplans', '0005_initial'),
        ('careteams', '0004_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0003_initial'),
        ('documentreferences', '0005_initial'),
        ('endpoints', '0001_initial'),
        ('groups', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingstudy',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_part_of', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='referrer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_referrer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='appointment_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='appointmentresponses.appointmentresponse'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_based_on', to='imagingstudies.imagingstudybasedonreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyprocedurereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_procedure_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_procedure', to='imagingstudies.imagingstudyprocedurereference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_reason', to='imagingstudies.imagingstudyreasonreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyreference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reference_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='body_site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='endpoint',
            field=models.ManyToManyField(related_name='imaging_study_series_endpoint', to='endpoints.endpointreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='laterality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_laterality', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='modality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_modality', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='specimen',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_specimen', to='specimens.specimenreference'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='series',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series', to='imagingstudies.imagingstudyseries'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='instance',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_instance', to='imagingstudies.imagingstudyseriesinstance'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_performer', to='imagingstudies.imagingstudyseriesperformer'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='imagingstudies.imagingstudyseriesperformeractorreference'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='groups.group'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject', to='imagingstudies.imagingstudysubjectreference'),
        ),
    ]



"""CareTeams views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import CareTeam
from .serializers import CareTeamSerializer


class CareTeamListView(APIView):
    """CareTeam list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: CareTeamSerializer(many=True)})
    def get(self, request):
        """Get a list of care teams."""
        care_teams = CareTeam.objects.all()
        serializer = CareTeamSerializer(care_teams, many=True)
        return Response(serializer.data)

    @extend_schema(request=CareTeamSerializer, responses={201: CareTeamSerializer})
    def post(self, request):
        """Create a care team."""
        serializer = CareTeamSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()

        return Response(serializer.data, status=status.HTTP_201_CREATED)


class CareTeamDetailView(APIView):
    """CareTeam detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get a care team object."""
        try:
            return CareTeam.objects.get(pk=pk)
        except CareTeam.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: CareTeamSerializer})
    def get(self, request, pk):
        """Get a care team."""
        care_team = self.get_object(pk)
        serializer = CareTeamSerializer(care_team)
        return Response(serializer.data)

    @extend_schema(request=CareTeamSerializer, responses={200: CareTeamSerializer})
    def put(self, request, pk):
        """Update a care team."""
        care_team = self.get_object(pk)
        serializer = CareTeamSerializer(care_team, data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()

        return Response(serializer.data)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete a care team."""
        care_team = self.get_object(pk)
        care_team.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Appointment responses choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class AppointmentResponseParticipantStatusChoices(models.TextChoices):
    """Appointment response participant status choices."""

    ACCEPTED = "accepted", _("Accepted")
    DECLINED = "declined", _("Declined")
    TENTATIVE = "tentative", _("Tentative")
    NEEDS_ACTION = "needs-action", _("Needs Action")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")



"""genomic study choices."""

from django.db.models import TextChoices
from django.utils.translation import gettext_lazy as _


class GenomicStudyStatusChoices(TextChoices):
    """genomic study status choices."""

    REGISTERED = "registered", _("Registered")
    AVAILABLE = "available", _("Available")
    CANCELLED = "cancelled", _("Cancelled")
    ENTER_IN_ERROR = "enter-in-error", _("Enter in Error")
    UNKNOWN = "unknown", _("Unknown")



"""Deviceassociations urls."""

from django.urls import path

from . import views

app_name = "deviceassociations"


urlpatterns = [
    path("deviceassociations/", views.DeviceAssociationListView.as_view()),
    path("deviceassociations/<int:pk>/", views.DeviceAssociationDetailView.as_view()),
]



"""Family member history app config."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class FamilymemberhistoriesConfig(AppConfig):
    """Family member history app config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.familymemberhistories"
    verbose_name = _("Family Member Histories")



"""inventory report models."""

from django.db import models

from dfhir.base.models import BaseReference, Identifier, TimeStampedModel
from dfhir.biologicallyderivedproducts.models import BiologicallyDerivedProduct
from dfhir.devices.models import Device
from dfhir.inventoryreports.choices import (
    InventoryReportCountTypeChoices,
    InventoryReportStatusChoices,
)
from dfhir.medications.models import Medication
from dfhir.nutritionproducts.models import NutritionProduct


class InventoryReportInventoryListingItemItemReference(BaseReference):
    """inventory report inventory listing item reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_reference_identifier",
    )
    medication = models.ForeignKey(
        Medication,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_medication",
    )
    device = models.ForeignKey(
        Device,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_device",
    )
    nutrition_product = models.ForeignKey(
        NutritionProduct,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_nutrition_product",
    )
    inventory_item = models.ForeignKey(
        "inventoryitems.InventoryItem",
        null=True,
        related_name="inventory_report_inventory_listing_item_inventory_item",
        on_delete=models.DO_NOTHING,
    )
    biologically_derived_product = models.ForeignKey(
        BiologicallyDerivedProduct,
        on_delete=models.DO_NOTHING,
        related_name="inventory_report_inventory_listing_item_biologically_derived_product",
    )


class InventoryReportInventoryListingItemItemCodeableReference(TimeStampedModel):
    """inventory report inventory listing item codeable reference."""

    concept = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_item_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        InventoryReportInventoryListingItemItemReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_item_codeable_reference_reference",
    )


class InventoryReportInventoryListingItem(TimeStampedModel):
    """inventory report inventory listing item."""

    category = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_category",
    )
    quality = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_quality",
    )
    item = models.ManyToManyField(
        InventoryReportInventoryListingItemItemReference,
        blank=True,
        related_name="inventory_report_inventory_listing_item",
    )


class InventoryReportInventoryListing(TimeStampedModel):
    """inventory report inventory listing model."""

    location = models.ForeignKey(
        "locations.LocationReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing",
    )
    item_status = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_inventory_listing_item_status",
    )
    counting_date_time = models.DateTimeField(null=True)
    item = models.ManyToManyField(
        InventoryReportInventoryListingItemItemCodeableReference,
        blank=True,
        related_name="inventory_report_inventory_listing",
    )


class InventoryReportReporterReference(BaseReference):
    """inventory report reporter reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_reporter_reference_identifier",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_reporter_reference_practitioner",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_reporter_reference_patient",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_reporter_reference_related_person",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_reporter_reference_device",
    )


class InventoryReport(TimeStampedModel):
    """inventory report model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="inventory_report", blank=True
    )
    status = models.CharField(
        max_length=255, null=True, choices=InventoryReportStatusChoices.choices
    )
    count_type = models.CharField(
        max_length=255, null=True, choices=InventoryReportCountTypeChoices.choices
    )
    operation_type = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_operational_type",
    )
    operation_type_reason = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report_operational_reason",
    )
    reported_date_time = models.DateTimeField(null=True)
    reporter = models.ForeignKey(
        InventoryReportReporterReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report",
    )
    reporting_period = models.ForeignKey(
        "base.Period",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="inventory_report",
    )
    inventory_listing = models.ManyToManyField(
        InventoryReportInventoryListing, related_name="inventory_report", blank=True
    )
    note = models.ManyToManyField(
        "base.Annotation", blank=True, related_name="inventory_report"
    )



"""Device metrics url."""

from django.urls import path

from . import views

app_name = "devicemetrics"

urlpatterns = [
    path("devicemetrics/", views.DeviceMetricListView.as_view()),
    path("devicemetrics/<int:pk>/", views.DeviceMetricDetailView.as_view()),
]



"""Healthcare services views."""

from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.generics import ListAPIView
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.base.models import ServiceType

from .models import ClinicalSpecialty, HealthcareService, ServiceCategory
from .serializers import (
    ClinicalSpecialtySerializer,
    HealthcareServiceSerializer,
    ServiceCategorySerializer,
    ServiceTypeSerializer,
)


class HealthcareServiceListView(APIView):
    """Healthcare Service list view."""

    serializer = HealthcareServiceSerializer
    permission_classes = [AllowAny]

    @extend_schema(responses={200, HealthcareServiceSerializer(many=True)})
    def get(self, request):
        """Get all healthcare services."""
        healthcare_services = HealthcareService.objects.all()
        serializer = self.serializer(healthcare_services, many=True)
        return Response(serializer.data)

    @extend_schema(
        request=HealthcareServiceSerializer,
        responses={201, HealthcareServiceSerializer},
    )
    def post(self, request):
        """Create a new healthcare service."""
        serializer = self.serializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class HealthcareServiceDetailView(APIView):
    """Healthcare Service detail view."""

    serializer = HealthcareServiceSerializer

    def get_object(self, pk=None):
        """Get healthcare service object."""
        try:
            return HealthcareService.objects.get(pk=pk)
        except HealthcareService.DoesNotExist:
            return Response(status=status.HTTP_404_NOT_FOUND)

    @extend_schema(responses={200, HealthcareServiceSerializer})
    def get(self, request, pk):
        """Get a healthcare service."""
        healthcare_service = self.get_object(pk)
        serializer = self.serializer(healthcare_service)
        return Response(serializer.data)

    @extend_schema(responses={200, HealthcareServiceSerializer})
    def patch(self, request, pk):
        """Update a healthcare service."""
        healthcare_service = self.get_object(pk)
        serializer = self.serializer(
            healthcare_service, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    def delete(self, request, pk):
        """Delete a healthcare service."""
        healthcare_service = self.get_object(pk)
        healthcare_service.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)


@extend_schema(responses={200, ServiceCategorySerializer(many=True)})
class ServiceCategoryListView(ListAPIView):
    """Service Category list view."""

    serializer_class = ServiceCategorySerializer
    queryset = ServiceCategory.objects.all()
    permission_classes = [AllowAny]


@extend_schema(responses={200, ClinicalSpecialtySerializer(many=True)})
class ClinicalSpecialtyValuesetListView(ListAPIView):
    """Clinical Specialty Valueset list view."""

    serializer_class = ClinicalSpecialtySerializer
    queryset = ClinicalSpecialty.objects.all()
    permission_classes = [AllowAny]


@extend_schema(responses={200, ServiceTypeSerializer(many=True)})
class ServiceTypeListView(ListAPIView):
    """Service Type list view."""

    serializer_class = ServiceTypeSerializer
    queryset = ServiceType.objects.all()
    permission_classes = [AllowAny]



"""Contract choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class ContractStatusChoices(models.TextChoices):
    """Contract status choices."""

    AMENDED = "amended", _("Amended")
    APPENDED = "appended", _("Appended")
    CANCELLED = "cancelled", _("Cancelled")
    DISPUTED = "disputed", _("Disputed")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")
    EXECUTED = "executed", _("Executed")
    EXECUTABLE = "executable", _("Executable")
    NEGOTIABLE = "negotiable", _("Negotiable")
    OFFERED = "offered", _("Offered")
    REJECTED = "rejected", _("Rejected")
    RENEWED = "renewed", _("Renewed")
    REVOKED = "revoked", _("Revoked")
    RESOLVED = "resolved", _("Resolved")
    TERMINATED = "terminated", _("Terminated")


class ContractContentDefinitionPublicationStatusChoices(models.TextChoices):
    """Contract content definition publication status choices."""

    AMENDED = "amended", _("Amended")
    APPENDED = "appended", _("Appended")
    CANCELLED = "cancelled", _("Cancelled")
    DISPUTED = "disputed", _("Disputed")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")
    EXECUTED = "executed", _("Executed")
    EXECUTABLE = "executable", _("Executable")
    NEGOTIABLE = "negotiable", _("Negotiable")
    OFFERED = "offered", _("Offered")
    REJECTED = "rejected", _("Rejected")
    RENEWED = "renewed", _("Renewed")
    REVOKED = "revoked", _("Revoked")
    RESOLVED = "resolved", _("Resolved")
    TERMINATED = "terminated", _("Terminated")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('activitydefinitions', '0008_initial'),
        ('base', '0005_initial'),
        ('groups', '0002_initial'),
        ('medications', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipant',
            name='type_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference', to='activitydefinitions.activitydefinitionparticipanttypereference'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='activitydefinition',
            name='product_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_reference', to='activitydefinitions.activitydefinitionproductproductreference'),
        ),
        migrations.AddField(
            model_name='activitydefinitionreference',
            name='activity_definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_reference', to='activitydefinitions.activitydefinition'),
        ),
        migrations.AddField(
            model_name='activitydefinitionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinitionsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='activitydefinitionsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinition',
            name='subject_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference', to='activitydefinitions.activitydefinitionsubjectreference'),
        ),
    ]



"""Allergy intolerance choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class AllergyIntoleranceCategory(models.TextChoices):
    """Allergy Intolerance category choices."""

    FOOD = "food", _("Food")
    MEDICATION = "medication", _("Medication")
    ENVIRONMENT = "environment", _("Environment")
    BIOLOGIC = "biologic", _("Biologic")


class AllergyIntoleranceCriticality(models.TextChoices):
    """Allergy Intolerance criticality choices."""

    LOW = "low", _("Low")
    HIGH = "high", _("High")
    UNABLE_TO_ASSESS = "unable-to-assess", _("Unable to Assess")


class AllergyIntoleranceSeverity(models.TextChoices):
    """Allergy Intolerance severity choices."""

    MILD = "mild", _("Mild")
    MODERATE = "moderate", _("Moderate")
    SEVERE = "severe", _("Severe")



"""Device usage apps."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class DeviceusagesConfig(AppConfig):
    """Device usage config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.deviceusages"
    verbose_name = _("Device Usages")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointments', '0004_initial'),
        ('base', '0005_initial'),
        ('careplans', '0004_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='careplanbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_based_on_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='care_plan_based_on', to='careplans.careplanbasedonreference'),
        ),
        migrations.CreateModel(
            name='CarePlanContributorReference',
            fields=[
                ('careplancustodianreference_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='careplans.careplancustodianreference')),
            ],
            options={
                'abstract': False,
            },
            bases=('careplans.careplancustodianreference',),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='devices.device'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='custodian_contributor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='patients.patient'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='careplancustodianreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='custodian',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_plan_custodian', to='careplans.careplancustodianreference'),
        ),
        migrations.AddField(
            model_name='careplandevicerequestreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_device_request_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='careplandevicerequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_device_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careplanplannedactivityreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_planned_activity_reference_appointment', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='careplanplannedactivityreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careplanplannedactivityreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_planned_activity_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='careplanplannedactivityreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_planned_activity_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='careplanactivity',
            name='planned_activity_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_activity_planned_activity_reference', to='careplans.careplanplannedactivityreference'),
        ),
        migrations.AddField(
            model_name='careplanreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='careplanreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='care_plan_part_of', to='careplans.careplanreference'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='replaces',
            field=models.ManyToManyField(blank=True, related_name='care_plan_replaces', to='careplans.careplanreference'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='contributor',
            field=models.ManyToManyField(blank=True, related_name='care_plan_contributor', to='careplans.careplancontributorreference'),
        ),
    ]



"""provenance choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class ProvenanceEntryRoleChoices(models.TextChoices):
    """provenance entry role choices."""

    REVISION = "revision", _("Revision")
    QUOTATION = "quotation", _("Quotation")
    SOURCE = "source", _("Source")
    INSTANTIATES = "instantiates", _("Instantiates")
    REMOVAL = "removal", _("Removal")



"""Device metrics Serializer."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    QuantitySerializer,
)
from dfhir.devices.serializers import DeviceReferenceSerializer

from .models import (
    DeviceMetric,
    DeviceMetricCalibration,
)


class DeviceMetricCalibrationSerializer(WritableNestedModelSerializer):
    """Device Metric Calibration Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DeviceMetricCalibration
        exclude = ["created_at", "updated_at"]


class DeviceMetricSerializer(BaseWritableNestedModelSerializer):
    """Device Metric Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    unit = CodeableConceptSerializer(many=False, required=False)
    device = DeviceReferenceSerializer(many=False, required=False)
    category = CodeableConceptSerializer(many=False, required=False)
    measurement_frequency = QuantitySerializer(many=False, required=False)
    calibration = DeviceMetricCalibrationSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DeviceMetric
        exclude = ["created_at", "updated_at"]



"""Practitioner Role models."""

from django.db import models

from dfhir.base.models import (
    Availability,
    BaseReference,
    CodeableConcept,
    ExtendedContactDetail,
    Identifier,
    OrganizationReference,
    Period,
    TimeStampedModel,
)
from dfhir.endpoints.models import EndpointReference
from dfhir.healthcareservices.models import HealthCareServiceReference
from dfhir.locations.models import LocationReference


class PractitionerRoleCode(TimeStampedModel):
    """Practitioner Role Code model."""

    display = models.CharField(max_length=255)
    definition = models.TextField(null=True)


class PractitionerRole(TimeStampedModel):
    """Practitioner Role model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="practitioner_role_identifier", blank=True
    )
    active = models.BooleanField(default=True)
    period = models.ForeignKey(
        Period, on_delete=models.DO_NOTHING, null=True, blank=True
    )
    practitioner = models.ForeignKey(
        "practitioners.PractitionerReference",
        on_delete=models.CASCADE,
        related_name="practitioner_role_practitioner",
    )
    organization = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        blank=True,
        related_name="practitioner_role_organization",
    )
    network = models.ManyToManyField(
        OrganizationReference, related_name="practitioner_role_network", blank=True
    )
    code = models.ManyToManyField(
        CodeableConcept, related_name="practitioner_role_code", blank=True
    )
    display = models.TextField(null=True)
    specialty = models.ManyToManyField(
        CodeableConcept, related_name="practitioner_role_specialty", blank=True
    )
    location = models.ManyToManyField(
        LocationReference, related_name="practitioner_role_location", blank=True
    )
    healthcare_service = models.ManyToManyField(
        HealthCareServiceReference, related_name="practitioner_role_healthcareservice"
    )
    contact = models.ManyToManyField(
        ExtendedContactDetail, related_name="practitioner_role_contact", blank=True
    )
    characteristic = models.ManyToManyField(
        CodeableConcept, related_name="practitioner_role_characteristic", blank=True
    )
    communication = models.ManyToManyField(
        CodeableConcept, related_name="practitioner_role_communication", blank=True
    )
    availability = models.ForeignKey(
        Availability,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="practitioner_role_availability",
    )
    endpoint = models.ManyToManyField(
        EndpointReference, related_name="practitioner_role_endpoint", blank=True
    )


class PractitionerRoleReference(BaseReference):
    """Practitioner Role Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="practitioner_role_reference_identifier",
    )
    practitioner_role = models.ForeignKey(
        PractitionerRole,
        on_delete=models.CASCADE,
        related_name="practitioner_role_reference_practitioner_role",
    )



"""diagnostic reports serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.base.serializers import (
    AnnotationSerializer,
    AttachmentSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CodeableReferenceSerializer,
    IdentifierSerializer,
    PeriodSerializer,
)
from dfhir.base.validators import validate_date_time_fields
from dfhir.communications.serializers import CommunicationReferenceSerializer
from dfhir.documentreferences.serializers import DocumentReferenceSerializer
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.observations.serializers import ObservationReferenceSerializer
from dfhir.specimens.serializers import SpecimenReferenceSerializer

from .models import (
    ConclusionCode,
    ConclusionCodeCodeableReference,
    ConclusionCodeReference,
    DiagnosticCategory,
    DiagnosticReport,
    DiagnosticReportBasedOnReference,
    DiagnosticReportCode,
    DiagnosticReportDocumentReferenceReference,
    DiagnosticReportMedia,
    DiagnosticReportPerformerReference,
    DiagnosticReportSubjectReference,
    SupportingInfo,
    SupportingInfoReference,
)

# TODO: from dfhir.observations.serializers import ObservationReferenceSerializer


class DiagnosticReportDocumentReferenceReferenceSerializer(
    BaseReferenceModelSerializer
):
    """diagnostic report document reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DiagnosticReportDocumentReferenceReference
        exclude = ["created_at", "updated_at"]


class DiagnosticReportBasedOnReferenceSerializer(BaseReferenceModelSerializer):
    """diagnostic report based on ref serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DiagnosticReportBasedOnReference
        exclude = ["created_at", "updated_at"]


class SubjectReferenceSerializer(BaseReferenceModelSerializer):
    """subject reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DiagnosticReportSubjectReference
        exclude = ["created_at", "updated_at"]


class DiagnosticReportMediaSerializer(WritableNestedModelSerializer):
    """diagnostic report media serializer."""

    link = DocumentReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = DiagnosticReportMedia
        exclude = ["created_at", "updated_at"]


class SupportingInfoReferenceSerializer(BaseReferenceModelSerializer):
    """supporting info reference serializer."""

    class Meta:
        """Meta class."""

        model = SupportingInfoReference
        exclude = ["created_at", "updated_at"]


class ConclusionCodeCodeableReferenceSerializer(WritableNestedModelSerializer):
    """conclusion code codeable reference serializer."""

    reference = CommunicationReferenceSerializer(many=False, required=False)
    concept = AttachmentSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ConclusionCodeCodeableReference
        exclude = ["created_at", "updated_at"]


class ConclusionCodeReferenceSerializer(BaseReferenceModelSerializer):
    """conclusion code reference serializer."""

    class Meta:
        """Meta class."""

        model = ConclusionCodeReference
        exclude = ["created_at", "updated_at"]


class DiagnosticReportPerformerSerializer(BaseReferenceModelSerializer):
    """diagnostic report performer serializer."""

    class Meta:
        """Meta class."""

        model = DiagnosticReportPerformerReference
        exclude = ["created_at", "updated_at"]


class SupportingInfoSerializer(WritableNestedModelSerializer):
    """diagnostic report supporting  serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    reference = SupportingInfoReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = SupportingInfo
        exclude = ["created_at", "updated_at"]


class DiagnosticReportSerializer(BaseWritableNestedModelSerializer):
    """diagnostic report serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    based_on = DiagnosticReportBasedOnReferenceSerializer(many=True, required=False)
    category = CodeableConceptSerializer(many=True, required=False)
    code = CodeableConceptSerializer(many=False, required=False)
    subject = SubjectReferenceSerializer(many=False, required=False)
    encounter = EncounterReferenceSerializer(many=False, required=False)
    effective_period = PeriodSerializer(many=False, required=False)
    performer = DiagnosticReportPerformerSerializer(many=True, required=False)
    results_interpretation = DiagnosticReportPerformerSerializer(
        many=True, required=False
    )
    specimen = SpecimenReferenceSerializer(many=True, required=False)
    supporting_info = SupportingInfoSerializer(many=True, required=False)
    media = DiagnosticReportMediaSerializer(many=True, required=False)
    results = ObservationReferenceSerializer(many=True, required=False)
    note = AnnotationSerializer(many=True, required=False)
    conclusion_code = ConclusionCodeCodeableReferenceSerializer(
        many=True, required=False
    )
    recommendation = CodeableReferenceSerializer(many=True, required=False)
    presented_form = AttachmentSerializer(many=True, required=False)
    communication = CommunicationReferenceSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DiagnosticReport
        exclude = ["created_at", "updated_at"]

    def validate(self, data):
        """Validate data."""
        validate_date_time_fields(
            data.get("effective_start_datetime"), data.get("effective_end_datetime")
        )
        return data


class ConclusionCodeSerializer(serializers.ModelSerializer):
    """conclusion code serializer."""

    class Meta:
        """Meta class."""

        model = ConclusionCode
        exclude = ["created_at", "updated_at"]


class DiagnosticCategorySerializer(serializers.ModelSerializer):
    """diagnostic category serializer."""

    class Meta:
        """Meta class."""

        model = DiagnosticCategory
        exclude = ["created_at", "updated_at"]


class DiagnosticReportCodeSerializer(serializers.ModelSerializer):
    """diagnostic report code serializer."""

    class Meta:
        """Meta class."""

        model = DiagnosticReportCode
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('chargeitems', '0004_initial'),
        ('claims', '0004_initial'),
        ('contracts', '0003_initial'),
        ('invoices', '0003_initial'),
        ('paymentreconciliations', '0002_initial'),
        ('tasks', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentreconciliation',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_request', to='tasks.taskreference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='charge_item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_charge_item', to='chargeitems.chargeitem'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_claim', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='contract',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_contract', to='contracts.contract'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='invoice',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_invoice', to='invoices.invoice'),
        ),
    ]



"""Locations URL Configuration."""

from django.urls import path

from .views import LocationDetail, LocationList

app_name = "locations"

urlpatterns = [
    path("locations/", LocationList.as_view(), name="location_list"),
    path("locations/<int:pk>/", LocationDetail.as_view(), name="location_detail"),
]



"""Group Urls."""

from django.urls import path

from . import views

app_name = "groups"

urlpatterns = [
    path("groups/", views.GroupListView.as_view()),
    path("groups/<int:pk>/", views.GroupDetailView.as_view()),
]



"""immunization evaluations URL Configuration."""

from django.urls import path

from dfhir.immunizationevaluations import views

app_name = "immunizationevaluations"

urlpatterns = [
    path("immunizationevaluations/", views.ImmunizationEvaluationListView.as_view()),
    path(
        "immunizationevaluations/<int:pk>",
        views.ImmunizationEvaluationDetailView.as_view(),
    ),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('bodystructures', '0002_initial'),
        ('claims', '0003_initial'),
        ('coverages', '0002_initial'),
        ('devicerequests', '0004_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0003_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('nutritionorders', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('supplyrequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claim',
            name='referral',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_referral', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='total',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_total', to='base.money'),
        ),
        migrations.AddField(
            model_name='claim',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claim',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='accident',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident', to='claims.claimaccident'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='specialty',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_specialty', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='claim_care_team', to='claims.claimcareteam'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider', to='claims.claimcareteamproviderreference'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='diagnosis_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_diagnosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='diagnosis_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_diagnosis_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='on_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_on_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='claim_diagnosis_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='claim_diagnosis', to='claims.claimdiagnosis'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='claim',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer', to='claims.claimentererreference'),
        ),
        migrations.AddField(
            model_name='claimevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_event_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claim',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='claim_event', to='claims.claimevent'),
        ),
        migrations.AddField(
            model_name='claiminsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='claiminsurance',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_insurance_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claim',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='claim_insurance', to='claims.claiminsurance'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='encounter',
            field=models.ManyToManyField(blank=True, related_name='claim_item_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claim',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='claim_item', to='claims.claimitem'),
        ),
        migrations.AddField(
            model_name='claimitembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='claimitembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_body_site', to='claims.claimitembodysite'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail', to='claims.claimitemdetail'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail', to='claims.claimitemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='supply_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_supply_request', to='supplyrequests.supplyrequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='claim_item_request', to='claims.claimitemrequestreference'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claim',
            name='original_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription', to='claims.claimoriginalprescriptionreference'),
        ),
        migrations.AddField(
            model_name='claimpayee',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee', to='claims.claimpayee'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='claimpayee',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party', to='claims.claimpayeepartyreference'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claim',
            name='prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription', to='claims.claimprescriptionreference'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='procedure_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_procedure_procedure_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='procedure_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_procedure_procedure_reference', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure', to='claims.claimprocedure'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claim',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider', to='claims.claimproviderreference'),
        ),
        migrations.AddField(
            model_name='claimreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_reference_claim', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='claimreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_claim', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='claim_related', to='claims.claimrelated'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='timing_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_timing_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='claim_supporting_info', to='claims.claimsupportinginfo'),
        ),
    ]



"""Encounter urls."""

from django.urls import path

from . import views

app_name = "encounters"

urlpatterns = [
    path("encounters/", views.EncounterListView.as_view()),
    path("encounters/<int:pk>/", views.EncounterDetailView.as_view()),
    path("encounters/conditions/", views.EncounterConditionListView.as_view()),
    path("encounters/diet/", views.DietPreferenceListView.as_view()),
    path("encounters/courtesy/", views.SpecialArrangementListView.as_view()),
    path("encounters/arrangement/", views.SpecialArrangementListView.as_view()),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('biologicallyderivedproducts', '0001_initial'),
        ('careteams', '0003_initial'),
        ('conditions', '0003_initial'),
        ('devicedefinitions', '0001_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('inventoryitems', '0002_initial'),
        ('locations', '0001_initial'),
        ('medications', '0001_initial'),
        ('nutritionproducts', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SupplyRequestDeliverFromReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_from_reference_identifier', to='base.identifier')),
                ('location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_from_reference_location', to='locations.location')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_from_reference_organization', to='organizations.organization')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestDeliverToReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to_reference_identifier', to='base.identifier')),
                ('location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to_reference_location', to='locations.location')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to_reference_organization', to='organizations.organization')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to_reference_patient', to='patients.patient')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to_reference_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestItemReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('biologically_derived_product', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct')),
                ('device', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_device', to='devices.device')),
                ('device_definition', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_device_definition', to='devicedefinitions.devicedefinition')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_identifier', to='base.identifier')),
                ('inventory_item', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_inventory_item', to='inventoryitems.inventoryitem')),
                ('medication', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_medication', to='medications.medication')),
                ('nutrition_product', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_nutrition_order', to='nutritionproducts.nutritionproduct')),
                ('substance', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_reference_substance', to='substances.substance')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestItemCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('concept', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_codeable_reference_concept', to='base.codeableconcept')),
                ('reference', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item_codeable_reference_reference', to='supplyrequests.supplyrequestitemreference')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestParameter',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value_boolean', models.BooleanField(null=True)),
                ('code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_parameter_code', to='base.codeableconcept')),
                ('value_codeable_concept', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_parameter_value_codeable_concept', to='base.codeableconcept')),
                ('value_quantity', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_parameter_value_quantity', to='base.quantity')),
                ('value_range', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_parameter_value_range', to='base.range')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestReasonCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('concept', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_codeable_reference_concept', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequest',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('draft', 'Draft'), ('active', 'Active'), ('suspended', 'Suspended'), ('cancelled', 'Cancelled'), ('completed', 'Completed'), ('entered-in-error', 'Entered in error'), ('unknown', 'Unknown')], max_length=200, null=True)),
                ('intent', models.CharField(choices=[('proposal', 'Proposal'), ('plan', 'Plan'), ('directive', 'Directive'), ('order', 'Order'), ('original-order', 'Original Order'), ('reflex-order', 'Reflex Order'), ('filler-order', 'Filler Order'), ('instance-order', 'Instance Order'), ('option', 'Option')], max_length=255, null=True)),
                ('priority', models.CharField(choices=[('routine', 'Routine'), ('urgent', 'Urgent'), ('stat', 'Stat'), ('asap', 'ASAP')], max_length=255, null=True)),
                ('occurrence_date_time', models.DateTimeField(blank=True, null=True)),
                ('authored_on', models.DateTimeField(blank=True, null=True)),
                ('based_on', models.ManyToManyField(blank=True, related_name='supply_request_based_on', to='base.reference')),
                ('category', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_category', to='base.codeableconcept')),
                ('deliver_for', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_for', to='patients.patientreference')),
                ('identifier', models.ManyToManyField(blank=True, related_name='supply_request_identifier', to='base.identifier')),
                ('occurrence_period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_occurrence_period', to='base.period')),
                ('occurrence_timing', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_occurrence_timing', to='base.timing')),
                ('quantity', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_quantity', to='base.quantity')),
                ('deliver_from', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_from', to='supplyrequests.supplyrequestdeliverfromreference')),
                ('deliver_to', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_deliver_to', to='supplyrequests.supplyrequestdelivertoreference')),
                ('item', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_item', to='supplyrequests.supplyrequestitemcodeablereference')),
                ('parameter', models.ManyToManyField(blank=True, related_name='supply_request_parameter', to='supplyrequests.supplyrequestparameter')),
                ('reason', models.ManyToManyField(blank=True, related_name='supply_request_reason', to='supplyrequests.supplyrequestreasoncodeablereference')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('condition', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_reference_condition', to='conditions.condition')),
                ('diagnostic_report', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport')),
                ('document_reference', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_reference_document_reference', to='documentreferences.documentreference')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_reference_identifier', to='base.identifier')),
                ('observation', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_reference_observation', to='observations.observation')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='supplyrequestreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reason_codeable_reference_reference', to='supplyrequests.supplyrequestreasonreference'),
        ),
        migrations.CreateModel(
            name='SupplyRequestReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reference_identifier', to='base.identifier')),
                ('supply_request', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_reference_supply_request', to='supplyrequests.supplyrequest')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SupplyRequestRequesterReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('care_team', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_care_team', to='careteams.careteam')),
                ('device', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_device', to='devices.device')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_organization', to='organizations.organization')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_patient', to='patients.patient')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_reques_requestert_reference_practitioner_role', to='practitionerroles.practitionerrole')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester_reference_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='supplyrequest',
            name='requester',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_requester', to='supplyrequests.supplyrequestrequesterreference'),
        ),
        migrations.CreateModel(
            name='SupplyRequestSupplierReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('healthcare_service', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_supplier_reference_healthcare_service', to='healthcareservices.healthcareservice')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_supplier_reference_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supply_request_supplier_reference_organization', to='organizations.organization')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='supplyrequest',
            name='supplier',
            field=models.ManyToManyField(blank=True, related_name='supply_request_supplier', to='supplyrequests.supplyrequestsupplierreference'),
        ),
    ]



"""Device usages urls."""

from django.urls import path

from . import views

app_name = "deviceusages"


urlpatterns = [
    path("deviceusages/", views.DeviceUsageListView.as_view()),
    path("deviceusages/<int:pk>/", views.DeviceUsageDetailView.as_view()),
]



"""Coverage urls."""

from django.urls import path

from . import views

app_name = "coverages"

urlpatterns = [
    path("coverages/", views.CoverageListView.as_view(), name="list_view"),
    path(
        "coverages/<int:pk>/",
        views.CoverageDetailView.as_view(),
        name="detail_view",
    ),
]



# Generated by Django 5.2.1 on 2025-07-21 00:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('activitydefinitions', '0011_alter_activitydefinition_kind'),
        ('base', '0005_initial'),
        ('plandefinitions', '0003_initial'),
        ('servicerequests', '0002_rename_medicatoin_request_servicerequestbasedonreference_medication_request_and_more'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ActivityPlanDefinitionReference',
            new_name='ActivityDefinitionPlanDefinitionReference',
        ),
    ]



"""medication administration urls."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    PeriodSerializer,
    QuantitySerializer,
    RatioSerializer,
    ReferenceSerializer,
    TimingSerializer,
)
from dfhir.careplans.serializers import CarePlanReferenceSerializer
from dfhir.devices.serializers import DeviceCodeableReferenceSerializer
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.medicationadministrations.models import (
    MedicationAdministration,
    MedicationAdministrationDosage,
    MedicationAdministrationPartOf,
    MedicationAdministrationPerformer,
    MedicationAdministrationPerformerActorCodeableReference,
    MedicationAdministrationPerformerActorReference,
    MedicationAdministrationReasonCodeableReference,
    MedicationAdministrationReasonReference,
)
from dfhir.medicationrequests.serializers import MedicationRequestReferenceSerializer
from dfhir.medications.serializers import MedicationCodeableReferenceSerializer
from dfhir.patients.serializers import PatientGroupReferenceSerializer
from dfhir.provenances.serializers import ProvenanceReferenceSerializer


class MedicationAdministrationPartOfSerializer(BaseReferenceModelSerializer):
    """medication administration part of serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta."""

        model = MedicationAdministrationPartOf
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationPerformerActorReferenceSerializer(
    BaseReferenceModelSerializer
):
    """medication administration performer actor serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta."""

        model = MedicationAdministrationPerformerActorReference
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationPerformerActorCodeableReferenceSerializer(
    WritableNestedModelSerializer
):
    """medication administration performer actor serializer."""

    concept = CodeableConceptSerializer(many=False, required=False)
    reference = MedicationAdministrationPerformerActorReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """meta options."""

        model = MedicationAdministrationPerformerActorCodeableReference
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationPerformerSerializer(WritableNestedModelSerializer):
    """medication administration performer serializer."""

    function = CodeableConceptSerializer(many=False, required=False)
    actor = MedicationAdministrationPerformerActorCodeableReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """Meta."""

        model = MedicationAdministrationPerformer
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationReasonReferenceSerializer(BaseReferenceModelSerializer):
    """medication administration reason reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = MedicationAdministrationReasonReference
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationReasonCodeableReferenceSerializer(
    WritableNestedModelSerializer
):
    """medication administration reason codeable reference serializer."""

    concept = CodeableConceptSerializer(many=False, required=False)
    reference = MedicationAdministrationReasonReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """meta options."""

        model = MedicationAdministrationReasonCodeableReference
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationDosageSerializer(WritableNestedModelSerializer):
    """medication administration dosage serializer."""

    site = CodeableConceptSerializer(many=False, required=False)
    route = CodeableConceptSerializer(many=False, required=False)
    method = CodeableConceptSerializer(many=False, required=False)
    dose = QuantitySerializer(many=False, required=False)
    rate_ratio = RatioSerializer(many=False, required=False)
    rate_quantity = QuantitySerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = MedicationAdministrationDosage
        exclude = ["created_at", "updated_at"]


class MedicationAdministrationSerializer(BaseWritableNestedModelSerializer):
    """medication administration serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    based_on = CarePlanReferenceSerializer(many=True, required=False)
    part_of = MedicationAdministrationPartOfSerializer(many=True, required=False)
    status_reason = CodeableConceptSerializer(many=True, required=False)
    category = CodeableConceptSerializer(many=True, required=False)
    medication = MedicationCodeableReferenceSerializer(many=False, required=False)
    subject = PatientGroupReferenceSerializer(many=False, required=False)
    encounter = EncounterReferenceSerializer(many=False, required=False)
    supporting_information = ReferenceSerializer(many=True, required=False)
    occurrence_period = PeriodSerializer(many=False, required=False)
    occurrence_timing = TimingSerializer(many=False, required=False)
    sub_potent_reason = CodeableConceptSerializer(many=True, required=False)
    performer = MedicationAdministrationPerformerSerializer(many=True, required=False)
    reason = MedicationAdministrationReasonCodeableReferenceSerializer(
        many=True, required=False
    )
    request = MedicationRequestReferenceSerializer(many=False, required=False)
    device = DeviceCodeableReferenceSerializer(many=True, required=False)
    note = AnnotationSerializer(many=True, required=False)
    dosage = MedicationAdministrationDosageSerializer(many=False, required=False)
    event_history = ProvenanceReferenceSerializer(many=True, required=False)

    class Meta:
        """meta options."""

        model = MedicationAdministration
        exclude = ["created_at", "updated_at"]



"""immunization recommendation models."""

from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    OrganizationReference,
    Reference,
    TimeStampedModel,
)
from dfhir.patients.models import PatientReference


class ImmunizationRecommendationRecommendationDateCriterion(TimeStampedModel):
    """immunization recommendation recommendation date criterion model."""

    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="immunization_recommendation_recommendation_date_criterion_code",
    )
    value = models.DateTimeField(null=True)


class ImmunizationRecommendationSupportingImmunizationReference(BaseReference):
    """immunization recommendation supporting immunization reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="immunization_recommendation_supporting_immunization_reference_identifier",
    )

    immunization = models.ForeignKey(
        "immunizations.Immunization",
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="immunization_recommendation_supporting_immunization_reference_immunization",
    )
    immunization_evolution = models.ForeignKey(
        "immunizationevaluations.ImmunizationEvaluation",
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="immunization_recommendation_supporting_immunization_reference_immunization_evolution",
    )


class ImmunizationRecommendationRecommendation(TimeStampedModel):
    """immunization recommendation recommendation model."""

    vaccine_code = models.ManyToManyField(
        CodeableConcept,
        related_name="immunization_recommendation_recommendation_vaccine_code",
        blank=True,
    )
    target_disease = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="immunization_recommendation_recommendation_target_disease",
    )
    contraindicated_vaccine_code = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="immunization_recommendation_recommendation_contraindicated_vaccine_code",
    )
    forecast_status = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        related_name="immunization_recommendation_recommendation_forecast_status",
        null=True,
    )
    forecast_reason = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="immunization_recommendation_recommendation_forecast_reason",
    )
    date_criterion = models.ManyToManyField(
        ImmunizationRecommendationRecommendationDateCriterion,
        blank=True,
        related_name="immunization_recommendation_recommendation_date_criterion",
    )
    description = models.TextField(null=True)
    series = models.CharField(max_length=255, null=True)
    dose_number = models.CharField(max_length=255, null=True)
    series_doses = models.CharField(max_length=255, null=True)
    supporting_information = models.ManyToManyField(
        ImmunizationRecommendationSupportingImmunizationReference,
        blank=True,
        related_name="immunization_recommendation_supporting_information",
    )
    supporting_patient_information = models.ManyToManyField(
        Reference,
        blank=True,
        related_name="immunization_recommendation_recommendation_supporting_patient_information",
    )


class ImmunizationRecommendation(TimeStampedModel):
    """immunization recommendation model."""

    identifier = models.ManyToManyField(
        Identifier, blank=True, related_name="immunization_recommendation_identifier"
    )
    patient = models.ForeignKey(
        PatientReference,
        on_delete=models.DO_NOTHING,
        related_name="immunization_recommendation_patient",
        null=True,
    )
    date = models.DateTimeField(null=True)
    authority = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="immunization_recommendation_authority",
    )
    recommendation = models.ManyToManyField(
        ImmunizationRecommendationRecommendation,
        blank=True,
        related_name="immunization_recommendation_recommendation",
    )



# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CommunicationBsedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommunicationPayload',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommunicationRecipientReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommunicationReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommunicationRequestReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CommunicationSenderReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Communication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('sent', models.DateTimeField(null=True)),
                ('received', models.DateTimeField(null=True)),
                ('about', models.ManyToManyField(blank=True, related_name='communication_about', to='base.reference')),
                ('category', models.ManyToManyField(blank=True, related_name='communication_category', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""Patient serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.base.serializers import (
    AddressSerializer,
    AttachmentSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CommunicationSerializer,
    ContactPointSerializer,
    HumanNameSerializer,
    IdentifierSerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
)
from dfhir.practitioners.serializers import (
    PractitionerOrganizationPractitionerRoleReferenceSerializer,
)

from .models import (
    Patient,
    PatientContact,
    PatientGroupReference,
    PatientLink,
    PatientOrganizationReference,
    PatientPractitionerReference,
    PatientReference,
    PatientRelatedPersonReference,
)


class PatientReferenceSerializer(BaseReferenceModelSerializer):
    """Patient reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PatientReference
        exclude = ["created_at", "updated_at"]


class PatientGroupReferenceSerializer(BaseReferenceModelSerializer):
    """Patient group reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = PatientGroupReference
        exclude = ["created_at", "updated_at"]


class PatientRelatedPersonReferenceSerializer(BaseReferenceModelSerializer):
    """Patient related person reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = PatientRelatedPersonReference
        exclude = ["created_at", "updated_at"]


class PatientLinkSerializer(serializers.ModelSerializer):
    """Patient link serializer."""

    class Meta:
        """Meta class."""

        model = PatientLink
        exclude = ["created_at", "updated_at"]


class PatientContactSerializer(WritableNestedModelSerializer):
    """Patient contact serializer."""

    name = HumanNameSerializer(required=False)
    telecom = ContactPointSerializer(many=True, required=False)
    organization = OrganizationReferenceSerializer(required=False)
    period = PeriodSerializer(required=False)
    address = AddressSerializer(required=False)
    relationship = CodeableConceptSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = PatientContact
        exclude = ["created_at", "updated_at"]


class PatientSerializer(BaseWritableNestedModelSerializer):
    """Patient serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    name = HumanNameSerializer(many=True, required=False)
    telecom = ContactPointSerializer(many=True, required=False)
    marital_status = CodeableConceptSerializer(required=False)
    photo = AttachmentSerializer(many=True, required=False)
    communication = CommunicationSerializer(many=True, required=False)
    contact = PatientContactSerializer(many=True, required=False)
    general_practitioner = PractitionerOrganizationPractitionerRoleReferenceSerializer(
        required=False
    )
    address = AddressSerializer(many=True, required=False)
    managing_organization = OrganizationReferenceSerializer(required=False)

    class Meta:
        """Meta class."""

        model = Patient
        exclude = ["created_at", "updated_at"]


class PatientOrganizationReferenceSerializer(BaseReferenceModelSerializer):
    """Patient organization reference serializer."""

    identifier = IdentifierSerializer(required=False, many=False)

    class Meta:
        """meta options."""

        model = PatientOrganizationReference
        exclude = ["created_at", "updated_at"]


class PatientPractitionerReferenceSerializer(BaseReferenceModelSerializer):
    """Patient Practitioner Reference Serializer."""

    identifier = IdentifierSerializer(required=False, many=False)

    class Meta:
        """Meta."""

        model = PatientPractitionerReference
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('adverseevents', '0008_initial'),
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0001_initial'),
        ('careteams', '0004_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('documentreferences', '0004_initial'),
        ('familymemberhistories', '0003_initial'),
        ('groups', '0002_initial'),
        ('immunizations', '0002_initial'),
        ('medicationadministrations', '0003_initial'),
        ('medicationrequests', '0002_initial'),
        ('medications', '0001_initial'),
        ('medicationstatements', '0003_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_codeable_reference_reference', to='adverseevents.adverseeventcontributingfactorreference'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='mitigating_action',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_mitigating_action', to='adverseevents.adverseeventmitigatingactioncodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactionreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactionreference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactionreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='adverseeventmitigatingactioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_mitigating_action_codeable_reference_reference', to='adverseevents.adverseeventmitigatingactionreference'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipant',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_participant_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='participant',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_participant', to='adverseevents.adverseeventparticipant'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipantactorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_participant_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='adverseeventparticipant',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_participant_actor', to='adverseevents.adverseeventparticipantactorreference'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='preventive_action',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_preventive_action', to='adverseevents.adverseeventpreventiveactioncodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactionreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='adverseeventpreventiveactioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_preventive_action_codeable_reference_reference', to='adverseevents.adverseeventpreventiveactionreference'),
        ),
        migrations.AddField(
            model_name='adverseeventrecorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_recorder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventrecorderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_recorder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='adverseeventrecorderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_recorder_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='adverseeventrecorderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_recorder_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='adverseeventrecorderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_recorder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='recorder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_recorder', to='adverseevents.adverseeventrecorderreference'),
        ),
        migrations.AddField(
            model_name='adverseeventsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='adverseeventsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='adverseeventsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='adverseeventsubjectreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_subject_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_subject', to='adverseevents.adverseeventsubjectreference'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginfocodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_supporting_info', to='adverseevents.adverseeventsupportinginfocodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='family_member_history',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_family_member_history', to='familymemberhistories.familymemberhistory'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginforeference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='adverseeventsupportinginfocodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_supporting_info_codeable_reference_reference', to='adverseevents.adverseeventsupportinginforeference'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='suspect_entity',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_suspect_entity', to='adverseevents.adverseeventsuspectentity'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityauthorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_author_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityauthorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_author_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityauthorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_author_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityauthorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_author_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityauthorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_author_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentitycausality',
            name='assessment_method',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_causality_assessment', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentitycausality',
            name='author',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_causality_author', to='adverseevents.adverseeventsuspectentityauthorreference'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentitycausality',
            name='entity_relatedness',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_causality_entity_relatedness', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentity',
            name='causality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_suspect_entity_causality', to='adverseevents.adverseeventsuspectentitycausality'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancecodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentity',
            name='instance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_suspect_entity_instance', to='adverseevents.adverseeventsuspectentityinstancecodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='biollogically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancereference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='adverseeventsuspectentityinstancecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_suspect_entity_instance_codeable_reference_reference', to='adverseevents.adverseeventsuspectentityinstancereference'),
        ),
    ]
